==> 9.1.2.zip: iClient-JavaScript-9.1.2/test/test-main-mapboxgl.js <==
/*mapboxgl -- control*/
import './mapboxgl/control/LogoSpec.js';

/*mapboxgl -- overlay*/
import './mapboxgl/overlay/mapv/MapvDataSetSpec.js';
import './mapboxgl/overlay/GraphThemeLayerSpec.js';
import './mapboxgl/overlay/HeatMapLayerSpec.js';
import './mapboxgl/overlay/LabelThemeLayerSpec.js';
import './mapboxgl/overlay/MapvLayerSpec.js';
import './mapboxgl/overlay/RangeThemeLayerSpec.js';
import './mapboxgl/overlay/RangeTheme3DLayerSpec.js';
import './mapboxgl/overlay/ThreeLayerSpec.js';
import './mapboxgl/overlay/UniqueThemeLayerSpec.js';
import './mapboxgl/overlay/UniqueTheme3DLayerSpec.js';
import './mapboxgl/overlay/DeckglLayerSpec.js';

import './mapboxgl/overlay/graphic/GraphicSpec.js';
import './mapboxgl/overlay/GraphicLayerSpec.js';
import './mapboxgl/overlay/mapv/MapvRenderSpec.js';

/*mapboxgl -- services*/
import './mapboxgl/services/AddressMatchServiceSpec.js';
import './mapboxgl/services/BufferAnalysisSpec.js';
import './mapboxgl/services/DataFlowServiceSpec.js';
import './mapboxgl/services/DensityAnalysisSpec.js';
import './mapboxgl/services/EditFeaturesSpec.js';
import './mapboxgl/services/FieldServiceSpec.js';
import './mapboxgl/services/GenerateSpatialDataSpec.js';
import './mapboxgl/services/GeoRelationAnalysisSpec.js';
import './mapboxgl/services/GeometryBatchAnalysisSpec.js';
import './mapboxgl/services/GetFeaturesByBoundsSpec.js';
import './mapboxgl/services/GetFeaturesByBufferSpec.js';
import './mapboxgl/services/GetFeaturesByGeometrySpec.js';
import './mapboxgl/services/GetFeaturesByIDsSpec.js';
import './mapboxgl/services/GetFeaturesBySQLSpec.js';
import './mapboxgl/services/GridCellInfosServiceSpec.js';
import './mapboxgl/services/InterpolationAnalysisSpec.js';
import './mapboxgl/services/LayerInfoServiceSpec.js';
import './mapboxgl/services/MapServiceSpec.js';
import './mapboxgl/services/MathExpressionAnalysisSpec.js';
import './mapboxgl/services/MeasureServiceSpec.js';
import './mapboxgl/services/NetworkAnalystServiceSpec.js';
import './mapboxgl/services/OverlayAnalysisSpec.js';
import './mapboxgl/services/ProcessingServiceSpec.js';
import './mapboxgl/services/QueryServiceSpec.js';
import './mapboxgl/services/RouteCalculateMeasureSpec.js';
import './mapboxgl/services/RouteLocateSpec.js';
import './mapboxgl/services/SurfaceAnalysisSpec.js';
import './mapboxgl/services/TerrainCurvatureCalculateSpec.js';
import './mapboxgl/services/ThemeServiceSpec.js';
import './mapboxgl/services/ThiessenAnalysisSpec.js';
import './mapboxgl/services/TrafficTransferAnalystServiceSpec.js';

/*mapboxgl -- mapping*/
import './mapboxgl/mapping/WebMapSpec.js';

==> 11.1.1.zip: iClient-JavaScript-11.1.1/test/test-main-mapboxgl.js <==
/*mapboxgl -- control*/
import './mapboxgl/control/LogoSpec.js';

/*mapboxgl -- overlay*/
import './mapboxgl/overlay/mapv/MapvDataSetSpec.js';
import './mapboxgl/overlay/GraphThemeLayerSpec.js';
import './mapboxgl/overlay/HeatMapLayerSpec.js';
import './mapboxgl/overlay/LabelThemeLayerSpec.js';
import './mapboxgl/overlay/MapvLayerSpec.js';
import './mapboxgl/overlay/RangeThemeLayerSpec.js';
import './mapboxgl/overlay/RangeTheme3DLayerSpec.js';
import './mapboxgl/overlay/ThreeLayerSpec.js';
import './mapboxgl/overlay/UniqueThemeLayerSpec.js';
import './mapboxgl/overlay/UniqueTheme3DLayerSpec.js';
import './mapboxgl/overlay/DeckglLayerSpec.js';
import './mapboxgl/overlay/graphic/GraphicSpec.js';
import './mapboxgl/overlay/GraphicLayerSpec.js';
import './mapboxgl/overlay/GraticuleLayerSpec.js';
import './mapboxgl/overlay/GraphMapSpec';
import './mapboxgl/overlay/symbol/CompositeSymbolRenderSpec';
import './mapboxgl/overlay/symbol/SingleSymbolRenderSpec';
import './mapboxgl/overlay/symbol/SymbolManagerSpec';
import './mapboxgl/overlay/symbol/WebSymbolSpec';
import './mapboxgl/overlay/symbol/SymbolHandlerSpec';
import './mapboxgl/overlay/symbol/SymbolUtilSpec';
import './mapboxgl/overlay/symbol/MapExtendSymbolSpec.js';

/*mapboxgl -- services*/
import './mapboxgl/services/KnowledgeGraphServiceSpec.js';
import './mapboxgl/services/AddressMatchServiceSpec.js';
import './mapboxgl/services/BufferAnalysisSpec.js';
import './mapboxgl/services/DataFlowServiceSpec.js';
import './mapboxgl/services/DensityAnalysisSpec.js';
import './mapboxgl/services/EditFeaturesSpec.js';
import './mapboxgl/services/FieldServiceSpec.js';
import './mapboxgl/services/GenerateSpatialDataSpec.js';
import './mapboxgl/services/GeoRelationAnalysisSpec.js';
import './mapboxgl/services/GeometryBatchAnalysisSpec.js';
import './mapboxgl/services/GeoprocessingServiceSpec.js';
import './mapboxgl/overlay/FGBLayerSpec.js';
import './mapboxgl/services/GetFeaturesByBoundsSpec.js';
import './mapboxgl/services/GetFeaturesByBufferSpec.js';
import './mapboxgl/services/GetFeaturesByGeometrySpec.js';
import './mapboxgl/services/GetFeaturesByIDsSpec.js';
import './mapboxgl/services/GetFeaturesBySQLSpec.js';
import './mapboxgl/services/GridCellInfosServiceSpec.js';
import './mapboxgl/services/InterpolationAnalysisSpec.js';
import './mapboxgl/services/LayerInfoServiceSpec.js';
import './mapboxgl/services/MapServiceSpec.js';
import './mapboxgl/services/MathExpressionAnalysisSpec.js';
import './mapboxgl/services/MeasureServiceSpec.js';
import './mapboxgl/services/NetworkAnalystServiceSpec.js';
import './mapboxgl/services/OverlayAnalysisSpec.js';
import './mapboxgl/services/ProcessingServiceSpec.js';
import './mapboxgl/services/QueryServiceSpec.js';
import './mapboxgl/services/RouteCalculateMeasureSpec.js';
import './mapboxgl/services/RouteLocateSpec.js';
import './mapboxgl/services/SurfaceAnalysisSpec.js';
import './mapboxgl/services/TerrainCurvatureCalculateSpec.js';
import './mapboxgl/services/TerrainAspectCalculateSpec.js';
import './mapboxgl/services/TerrainSlopeCalculateSpec.js';
import './mapboxgl/services/TerrainCutFillCalculateSpec.js';
import './mapboxgl/services/MinDistanceAnalysisSpec.js';
import './mapboxgl/services/ConvexHullAnalysisSpec.js';
import './mapboxgl/services/ThemeServiceSpec.js';
import './mapboxgl/services/ThiessenAnalysisSpec.js';
import './mapboxgl/services/TrafficTransferAnalystServiceSpec.js';
import './mapboxgl/services/WebPrintingJobServiceSpec.js';
import './mapboxgl/services/DatasetServiceSpec.js';
import './mapboxgl/services/DatasourceServiceSpec.js';
import './mapboxgl/services/ImageServiceSpec';
import './mapboxgl/services/ImageCollectionServiceSpec';

/*mapboxgl -- mapping*/
import './mapboxgl/mapping/WebMapSpec.js';
import './mapboxgl/mapping/InitMapSpec.js';
